pub enum Feature {
Enable,
Disable,
Keep,
Error,
}Expand description
Set the behavior for a feature flag during conditional translation.
Keepmeans that the feature flag will be left as-is. This is useful for incremental compilation, e.g. for generating shader variantsErrormeans that unspecified feature flags will trigger aCondCompError::UnexpectedFeatureFlag.
Default is Disable.
Variants