pub struct StandardResolver { /* private fields */ }Expand description
The resolver that implements the WESL standard.
It resolves modules in external packages registered with Self::add_package and
modules in the local package with the filesystem.
Implementations
Sourceimpl StandardResolver
impl StandardResolver
Sourcepub fn new(base: impl AsRef<Path>) -> Self
pub fn new(base: impl AsRef<Path>) -> Self
Create a new resolver.
base is the root directory which absolute paths refer to.
Sourcepub fn add_package(&mut self, pkg: &'static CodegenPkg)
pub fn add_package(&mut self, pkg: &'static CodegenPkg)
Add an external package.
Sourcepub fn add_constant(&mut self, name: impl ToString, value: LiteralInstance)
pub fn add_constant(&mut self, name: impl ToString, value: LiteralInstance)
Add a numeric constant.
Numeric constants live WESL’s special package named constants. This package is
virtual, meaning it doesn’t exist on the filesystem. Constants can be accessed
by importing them: import constants::MY_CONSTANT;.
The type is specified by the variant of LiteralInstance.
If specifying a constant that is used with multiple different types or
a constant that benefits from precision, like π, use AbstractFloat,
which can be implicitly converted to all scalar types.
Note: LiteralInstance implements From for all standard numeric types