pub struct ParenthesizedExpression {
pub expression: Spanned<Expression>,
}Fields
expression: Spanned<Expression>Trait Implementations
Sourceimpl Clone for ParenthesizedExpression
impl Clone for ParenthesizedExpression
Sourcefn clone(&self) -> ParenthesizedExpression
fn clone(&self) -> ParenthesizedExpression
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParenthesizedExpression
impl Debug for ParenthesizedExpression
Sourceimpl<'de> Deserialize<'de> for ParenthesizedExpression
impl<'de> Deserialize<'de> for ParenthesizedExpression
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ParenthesizedExpression, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ParenthesizedExpression, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ParenthesizedExpression
impl Display for ParenthesizedExpression
Sourceimpl Eval for ParenthesizedExpression
Available on crate feature eval only.
impl Eval for ParenthesizedExpression
Available on crate feature
eval only.Sourceimpl EvalTy for ParenthesizedExpression
Available on crate feature eval only.
impl EvalTy for ParenthesizedExpression
Available on crate feature
eval only.Sourcefn eval_ty(&self, ctx: &mut Context<'_>) -> Result<Type, EvalError>
fn eval_ty(&self, ctx: &mut Context<'_>) -> Result<Type, EvalError>
Evaluate the type of an expression, without evaluating the expression itself (static analysis).
We mean a ‘real’ expression, not a template expression resolving to a type. Refer to
ty_eval_ty To evaluate the type of a type-expression.Sourceimpl From<ParenthesizedExpression> for Expression
impl From<ParenthesizedExpression> for Expression
Sourcefn from(value: ParenthesizedExpression) -> Expression
fn from(value: ParenthesizedExpression) -> Expression
Converts to this type from the input type.
Sourceimpl PartialEq for ParenthesizedExpression
impl PartialEq for ParenthesizedExpression
Sourceimpl Serialize for ParenthesizedExpression
impl Serialize for ParenthesizedExpression
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ParenthesizedExpression
Sourceimpl SyntaxNode for ParenthesizedExpression
impl SyntaxNode for ParenthesizedExpression
Sourcefn attributes(&self) -> &[Spanned<Attribute>]
fn attributes(&self) -> &[Spanned<Attribute>]
List all attributes of a syntax node.
Sourcefn attributes_mut(&mut self) -> &mut [Spanned<Attribute>]
fn attributes_mut(&mut self) -> &mut [Spanned<Attribute>]
List all attributes of a syntax node.
Sourcefn contains_attribute(&self, attribute: &Attribute) -> bool
fn contains_attribute(&self, attribute: &Attribute) -> bool
Whether the node contains an attribute.